@@ -1,5 +1,5 @@
 package POEx::Weather::OpenWeatherMap;
-$POEx::Weather::OpenWeatherMap::VERSION = '0.002002';
+$POEx::Weather::OpenWeatherMap::VERSION = '0.003001';
 use Defaults::Modern;
 
 use POE 'Component::Client::HTTP';
@@ -23,11 +23,14 @@ with 'MooX::Role::POE::Emitter';
 
 
 has api_key => (
-  lazy        => 1,
   is          => 'ro',
   isa         => Str,
   predicate   => 1,
-  builder     => sub { '' },
+  writer      => 'set_api_key',
+  builder     => sub {
+    carp "No api_key specified, requests will likely fail!";
+    ''
+  },
 );
 
 has _ua_alias => (
@@ -110,6 +113,13 @@ sub mxrp_emitter_started {
 
 sub mxrp_emitter_stopped {
   my ($kernel, $self) = @_[KERNEL, OBJECT];
+  # expire stale cache items before we stop if we have a persistent cache_dir;
+  # elsewise clear cache entirely:
+  if (defined $self->cache_dir) {
+    $self->_cache->expire_all
+  } else {
+    $self->_cache->clear
+  }
   $kernel->call( $self->_ua_alias => 'shutdown' )
     if $kernel->alias_resolve( $self->_ua_alias );
 }
@@ -245,7 +255,7 @@ sub ext_http_response {
 
 =pod
 
-=for Pod::Coverage ext_\w+ mxrp_\w+ has_\w+
+=for Pod::Coverage ext_\w+ mxrp_\w+ has_\w+ set_api_key
 
 =head1 NAME
 
@@ -350,6 +360,9 @@ Your L<OpenWeatherMap|http://www.openweathermap.org> API key.
 
 (See L<http://www.openweathermap.org/api> to register for free.)
 
+C<api_key> can be set after object construction via B<set_api_key>; if the key
+is not valid, requests will likely fail with C<< 401 Unauthorized >> errors.
+
 =head3 cache
 
 A boolean value indicating whether successful results should be cached to disk
